<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Ignore reCaptcha on confirmation screen
 *
 */
function wpbs_validate_recaptcha_payment_confirmation_authorize_net($response, $form_data)
{
    if (isset($form_data['wpbs-authorize-net-confirmation-loaded']) && $form_data['wpbs-authorize-net-confirmation-loaded'] == '1') {
        return true;
    }
    return $response;
}
add_filter('wpbs_validate_recaptcha_payment_confirmation', 'wpbs_validate_recaptcha_payment_confirmation_authorize_net', 10, 2);

/**
 * Show the payment confirmation page after submitting the form
 *
 */
function wpbs_an_submit_form_payment_confirmation($response, $post_data, $form, $form_args, $form_fields, $calendar_id)
{

    // Check if another payment method was already found
    if ($response !== false) {
        return $response;
    }

    $payment_found = false;

    // Check if payment method is enabled.
    foreach ($form_fields as $form_field) {
        if ($form_field['type'] == 'payment_method' && $form_field['user_value'] == 'authorize_net') {
            $payment_found = true;
            break;
        }
    }

    if ($payment_found === false) {
        return false;
    }

    // Parse POST data
    parse_str($post_data['form_data'], $form_data);

    // Check if the payment screen was shown
    if (isset($form_data['wpbs-authorize-net-confirmation-loaded']) && $form_data['wpbs-authorize-net-confirmation-loaded'] == '1') {
        return false;
    }

    // Add a field to the input so we can check if the payment screen was already shown
    add_filter('wpbs_form_outputter_form_fields_after', function () {
        return '<input type="hidden" name="wpbs-authorize-net-confirmation-loaded" value="1" />';
    });

    // Generate form
    $form_outputter = new WPBS_Form_Outputter($form, $form_args, $form_fields, $calendar_id);

    // Check if post data exists and matches form values
    if (wpbs_validate_payment_form_consistency($form_fields) === false) {
        return json_encode(
            array(
                'success' => false,
                'html' => '<strong>' . __('Something went wrong. Please refresh the page and try again.', 'wp-booking-system-authorize-net') . '</strong>',
            )
        );
    }

    // Get price
    $payment = new WPBS_Payment;
    $payment->calculate_prices($post_data, $form, $form_args, $form_fields);

    $total = $payment->get_total();
    

    // Check if part payments are used
    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $total = $payment->get_total_first_payment();
    }

    // Check if price is greater than the minimum allowed, 0.01;
    if ($total <= 0.01) {
        return json_encode(
            array(
                'success' => false,
                'html' => '<p class="wpbs-form-general-error">' . __("The minimum payable amount is 0.01$", 'wp-booking-system-authorize-net') . '</p>',
            )
        );
    }

    if (!in_array($payment->get_currency(), wpbs_an_supported_currencies())) {
        return json_encode(
            array(
                'success' => false,
                'html' => '<p class="wpbs-form-general-error">' . __("This currency is not supported by Authorize.Net", 'wp-booking-system-authorize-net') . '</p>',
            )
        );
    }

    // Include Authorize.Net SDK
    include_once WPBS_AN_PLUGIN_DIR . 'includes/libs/authorize-net-sdk/authorize-net-sdk.php';

    // Get API Keys
    $api = WPBS_AuthorizeNet_API::keys();
    $script_src = WPBS_AuthorizeNet_API::script();

    /**
     * Prepare Response
     *
     */
    $authorize_net_output = '';
    if ($api['environment'] == 'sandbox') {
        $authorize_net_output .= '<p class="wpbs-payment-test-mode-enabled">' . __('Authorize.Net Test mode is enabled.', 'wp-booking-system-authorize-net') . '</p>';
    }

    $authorize_net_output .= '
        <div id="wpbs-authorize-net-button-container">
            <script src="'.$script_src.'" charset="utf-8"></script>
            <div class="wpbs-authorize-net-form-error"></div>';

    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $authorize_net_output .= '<label>' . wpbs_get_payment_default_string('amount_billed', $form_outputter->get_language()) . '</label><input class="wpbs-payment-confirmation-authorize-net-input" type="text" value="' . wpbs_get_formatted_price($total, $payment->get_currency()) . '" readonly>';
    }
    
    $authorize_net_output .= '
        
            <label>' . wpbs_get_payment_default_string('card_details', $form_outputter->get_language()) . '</label>
            <input type="tel" name="wpbs_authorize_net_card_number" id="wpbs_authorize_net_card_number" placeholder="Card number" autocomplete="cc-number" autocompletetype="cc-number" x-autocompletetype="cc-number" /> 
            <input type="tel" name="wpbs_authorize_net_exp_date" id="wpbs_authorize_net_exp_date" placeholder="MM / YY" autocomplete="cc-exp" />
            <input type="tel" name="wpbs_authorize_net_cvc" maxlength="4" id="wpbs_authorize_net_cvc" placeholder="CVC" autocomplete="off"/> 
            <label>' . wpbs_get_payment_default_string('cardholder_name', $form_outputter->get_language()) . '</label>
            <input type="text" name="wpbs_authorize_net_cardholder_name" id="wpbs_authorize_net_cardholder_name" placeholder=""/>
            <button type="button" id="wpbs-authorize-net-submit">'.wpbs_get_payment_default_string('payment_submit', $form_outputter->get_language()).'</button>
            <div class="wpbs-authorize-net-powered-by"><img src="' . WPBS_AN_PLUGIN_DIR_URL . 'assets/img/powered-by-authorize-net.png" /></div>
        </div>
        <script type="text/javascript">
           
            var cleave_cc = new Cleave("#wpbs_authorize_net_card_number", {
                creditCard: true
            });

            var cleave_exp = new Cleave("#wpbs_authorize_net_exp_date", {
                date: true,
                delimiter: " / ",
                datePattern: ["m", "y"]
            });

            var cleave_cvc = new Cleave("#wpbs_authorize_net_cvc", {
                numeral: true,
                delimiter: "",
                stripLeadingZeroes: false
            });
        
            jQuery("body").on("click","#wpbs-authorize-net-submit",function(e){
                e.preventDefault();
                jQuery(".wpbs-authorize-net-form-error").empty();
                jQuery(this).prop("disabled", true);
                wpbs_send_data_to_authorize_net();
            })

            function wpbs_send_data_to_authorize_net() {
                
                var authData = {};
                    authData.clientKey = "'.$api['client_key'].'";
                    authData.apiLoginID = "'.$api['api_login_id'].'";

                var exp_month = (jQuery("#wpbs_authorize_net_exp_date").val().split("/")[0]) ? jQuery("#wpbs_authorize_net_exp_date").val().split("/")[0].trim() : false;
                var exp_year = (jQuery("#wpbs_authorize_net_exp_date").val().split("/")[1]) ? jQuery("#wpbs_authorize_net_exp_date").val().split("/")[1].trim() : false;

                var cardData = {};
                    cardData.cardNumber = jQuery("#wpbs_authorize_net_card_number").val().replace(/\s/g, "");
                    cardData.month = exp_month;
                    cardData.year = exp_year;
                    cardData.cardCode = jQuery("#wpbs_authorize_net_cvc").val();
                
                var secureData = {};
                    secureData.authData = authData;
                    secureData.cardData = cardData;

                Accept.dispatchData(secureData, wpbs_handle_authorize_net_response);

                function wpbs_handle_authorize_net_response(response) {
                    if (response.messages.resultCode === "Error") {
                        jQuery(".wpbs-authorize-net-form-error").append("<p>"+response.messages.message[0].text+"</p>")
                        jQuery("#wpbs-authorize-net-submit").prop("disabled", false);
                    } else {
                        
                        document.getElementById("wpbs_authorize_net_card_number").value = "";
                        document.getElementById("wpbs_authorize_net_exp_date").value = "";
                        document.getElementById("wpbs_authorize_net_cvc").value = "";

                        jQuery(".wpbs-authorize-net-payment-confirmation-inner-' . $form_outputter->get_unique() . '").hide();
                        jQuery(".wpbs-authorize-net-payment-confirmation-' . $form_outputter->get_unique() . '").append("<h4>' . wpbs_get_payment_default_string('processing_payment', $form_outputter->get_language()) . '</h4>");
                        jQuery(".wpbs-authorize-net-payment-confirmation-' . $form_outputter->get_unique() . '").append("<div class=\"wpbs-overlay\"><div class=\"wpbs-overlay-spinner\"><div class=\"wpbs-overlay-bounce1\"></div><div class=\"wpbs-overlay-bounce2\"></div><div class=\"wpbs-overlay-bounce3\"></div></div></div>");
                        jQuery(".wpbs-authorize-net-payment-confirmation-' . $form_outputter->get_unique() . ' form").append("<input type=\"hidden\" name=\"wpbs-authorize-net-descriptor\" value=\""+response.opaqueData.dataDescriptor+"\" />")
                        jQuery(".wpbs-authorize-net-payment-confirmation-' . $form_outputter->get_unique() . ' form").append("<input type=\"hidden\" name=\"wpbs-authorize-net-value\" value=\""+response.opaqueData.dataValue+"\" />")
                        jQuery(".wpbs-authorize-net-payment-confirmation-' . $form_outputter->get_unique() . ' form").submit();
                    }
                }
            
            }

            jQuery("#wpbs-authorize-net-button-container-' . $form_outputter->get_unique() . '").parents(".wpbs-main-wrapper").find(".wpbs-container").addClass("wpbs-disable-selection");
        </script>
    ';

    $output = wpbs_form_payment_confirmation_screen($form_outputter, $payment, 'authorize-net', $authorize_net_output);

    return json_encode(
        array(
            'success' => false,
            'html' => $output,
        )
    );

}
add_filter('wpbs_submit_form_before', 'wpbs_an_submit_form_payment_confirmation', 20, 6);


/**
 * Save the order in the database
 *
 */
function wpbs_an_action_save_payment_details($booking_id, $post_data, $form, $form_args, $form_fields)
{

    // Parse POST data
    parse_str($post_data['form_data'], $form_data);

    // Check if Authorize.Net is enabled
    if (!isset($form_data['wpbs-authorize-net-confirmation-loaded'])) {
        return false;
    }

    // Check if we got an order ID
    if (!isset($form_data['wpbs-authorize-net-value'])) {
        return false;
    }

    // Include Authorize.Net SDK
    include_once WPBS_AN_PLUGIN_DIR . 'includes/libs/authorize-net-sdk/authorize-net-sdk.php';

    // Get price
    $payment = new WPBS_Payment;

    $details['price'] = $payment->calculate_prices($post_data, $form, $form_args, $form_fields);

    $total = $payment->get_total();

    // Check if part payments are used
    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $total = $payment->get_total_first_payment();
        $details['part_payments'] = array('deposit' => false, 'final_payment' => false);
    }

    // Get plugin settings
    $settings = get_option('wpbs_settings', array());

    // Invoice item description
    $invoice_item_description = (!empty($settings['payment_authorize_net_invoice_name_translation_' . $form_args['language']])) ? $settings['payment_authorize_net_invoice_name_translation_' . $form_args['language']] : (!empty($settings['payment_authorize_net_invoice_name']) ? $settings['payment_authorize_net_invoice_name'] : get_bloginfo('name') . ' Booking');


    // Capture Order
    $transaction = WPBS_AuthorizeNet::createAnAcceptPaymentTransaction($total, $form_data['wpbs-authorize-net-value'], $booking_id, $invoice_item_description);
    
    if ($transaction['status'] == 'success') {
        // Get Order
        $order = WPBS_AuthorizeNet::getTransactionDetails($transaction['transaction_id']);

        $details['raw'] = $order;

        if (isset($details['part_payments']['deposit'])) {
            $details['part_payments']['deposit'] = true;
        }

        $status = 'completed';
        $id = $transaction['transaction_id'];
    } else {
        $details['error'] = $transaction['error_code'] . ': ' . $transaction['error_message'];
        $status = 'error';
        $id = 'N/A';
    }

    // Save Order
    wpbs_insert_payment(array(
        'booking_id' => $booking_id,
        'gateway' => 'authorize_net',
        'order_id' => $id,
        'order_status' => $status,
        'details' => $details,
        'date_created' => current_time('Y-m-d H:i:s'),
    ));

}
add_action('wpbs_submit_form_after', 'wpbs_an_action_save_payment_details', 20, 5);
