<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Display the final payment of the part payments checkout form.
 *
 * @param string $output
 * @param WPBS_Payment $payment
 * @param string $language
 *
 * @return string
 *
 */
function wpbs_final_payment_authorize_net($output, $payment, $language)
{

    // Get total amount
    $total = $payment->get_total_second_payment();

    // Include Authorize.Net SDK
    include_once WPBS_AN_PLUGIN_DIR . 'includes/libs/authorize-net-sdk/authorize-net-sdk.php';

    // Get API Keys
    $api = WPBS_AuthorizeNet_API::keys();
    $script_src = WPBS_AuthorizeNet_API::script();

    /**
     * Prepare Response
     *
     */

    $output = '';
    if ($api['environment'] == 'sandbox') {
        $output .= '<p class="wpbs-payment-test-mode-enabled">' . __('Authorize.Net Test mode is enabled.', 'wp-booking-system-authorize-net') . '</p>';
    }

    $output .= '
        <div id="wpbs-authorize-net-button-container">
            <script src="' . $script_src . '" charset="utf-8"></script>
            <div class="wpbs-authorize-net-form-error"></div>';

    $output .= '<label>' . wpbs_get_payment_default_string('amount_billed', $language) . '</label>';
    $output .= '<input class="wpbs-payment-confirmation-authorize-net-input" type="text" value="' . wpbs_get_formatted_price($total, $payment->get_currency()) . '" readonly>';

    $output .= '
       <label>' . wpbs_get_payment_default_string('card_details', $language) . '</label>
            <input type="tel" name="wpbs_authorize_net_card_number" id="wpbs_authorize_net_card_number" placeholder="Card number" autocomplete="cc-number" autocompletetype="cc-number" x-autocompletetype="cc-number" />
            <input type="tel" name="wpbs_authorize_net_exp_date" id="wpbs_authorize_net_exp_date" placeholder="MM / YY" autocomplete="cc-exp" />
            <input type="tel" name="wpbs_authorize_net_cvc" maxlength="4" id="wpbs_authorize_net_cvc" placeholder="CVC" autocomplete="off"/>
            <label>' . wpbs_get_payment_default_string('cardholder_name', $language) . '</label>
            <input type="text" name="wpbs_authorize_net_cardholder_name" id="wpbs_authorize_net_cardholder_name" placeholder=""/>
            <button type="button" id="wpbs-authorize-net-submit">' . wpbs_get_payment_default_string('payment_submit', $language) . '</button>
            <div class="wpbs-authorize-net-powered-by"><img src="' . WPBS_AN_PLUGIN_DIR_URL . 'assets/img/powered-by-authorize-net.png" /></div>
        </div>
        <script type="text/javascript">

            var cleave_cc = new Cleave("#wpbs_authorize_net_card_number", {
                creditCard: true
            });

            var cleave_exp = new Cleave("#wpbs_authorize_net_exp_date", {
                date: true,
                delimiter: " / ",
                datePattern: ["m", "y"]
            });

            var cleave_cvc = new Cleave("#wpbs_authorize_net_cvc", {
                numeral: true,
                delimiter: "",
                stripLeadingZeroes: false
            });

            jQuery("body").on("click","#wpbs-authorize-net-submit",function(e){
                e.preventDefault();
                jQuery(".wpbs-authorize-net-form-error").empty();
                jQuery(this).prop("disabled", true);
                wpbs_send_data_to_authorize_net();
            })

            function wpbs_send_data_to_authorize_net() {

                var authData = {};
                    authData.clientKey = "' . $api['client_key'] . '";
                    authData.apiLoginID = "' . $api['api_login_id'] . '";

                var exp_month = (jQuery("#wpbs_authorize_net_exp_date").val().split("/")[0]) ? jQuery("#wpbs_authorize_net_exp_date").val().split("/")[0].trim() : false;
                var exp_year = (jQuery("#wpbs_authorize_net_exp_date").val().split("/")[1]) ? jQuery("#wpbs_authorize_net_exp_date").val().split("/")[1].trim() : false;

                var cardData = {};
                    cardData.cardNumber = jQuery("#wpbs_authorize_net_card_number").val().replace(/\s/g, "");
                    cardData.month = exp_month;
                    cardData.year = exp_year;
                    cardData.cardCode = jQuery("#wpbs_authorize_net_cvc").val();

                var secureData = {};
                    secureData.authData = authData;
                    secureData.cardData = cardData;

                Accept.dispatchData(secureData, wpbs_handle_authorize_net_response);

                function wpbs_handle_authorize_net_response(response) {
                    if (response.messages.resultCode === "Error") {
                        jQuery(".wpbs-authorize-net-form-error").append("<p>"+response.messages.message[0].text+"</p>")
                        jQuery("#wpbs-authorize-net-submit").prop("disabled", false);
                    } else {

                        document.getElementById("wpbs_authorize_net_card_number").value = "";
                        document.getElementById("wpbs_authorize_net_exp_date").value = "";
                        document.getElementById("wpbs_authorize_net_cvc").value = "";

                        jQuery(".wpbs-authorize-net-payment-confirmation-inner").hide();
                        jQuery("#wpbs-authorize-net-button-container").hide();
                        jQuery(".wpbs-final-payment-confirmation").append("<h4>' . wpbs_get_payment_default_string('processing_payment', $language) . '</h4>");
                        jQuery(".wpbs-final-payment-confirmation").append("<div class=\"wpbs-overlay\"><div class=\"wpbs-overlay-spinner\"><div class=\"wpbs-overlay-bounce1\"></div><div class=\"wpbs-overlay-bounce2\"></div><div class=\"wpbs-overlay-bounce3\"></div></div></div>");
                        jQuery(".wpbs-final-payment-confirmation form").append("<input type=\"hidden\" name=\"wpbs-authorize-net-descriptor\" value=\""+response.opaqueData.dataDescriptor+"\" />")
                        jQuery(".wpbs-final-payment-confirmation form").append("<input type=\"hidden\" name=\"wpbs-authorize-net-value\" value=\""+response.opaqueData.dataValue+"\" />")
                        jQuery(".wpbs-final-payment-confirmation form").submit();
                    }
                }

            }

        </script>
    ';

    return $output;

}
add_filter('wpbs_final_payment_authorize_net', 'wpbs_final_payment_authorize_net', 10, 3);

/**
 * Process the final payment of the part payments checkout form.
 *
 * @param array $post_data
 * @param WPBS_Payment $payment
 *
 */
function wpbs_save_final_payment_authorize_net($post_data, $payment)
{

    // Check if we got an order ID
    if (!isset($post_data['wpbs-authorize-net-value'])) {
        return wp_die();
    }

    // Get site options
    $settings = get_option('wpbs_settings', array());

    // Include Authorize.Net SDK
    include_once WPBS_AN_PLUGIN_DIR . 'includes/libs/authorize-net-sdk/authorize-net-sdk.php';

    // Get price
    $details = $payment->get('details');

    // Check if final payment wasn't made yet
    if ($payment->is_final_payment_paid()) {
        wp_die();
    }

    // Get total amount
    $prices = $details['price'];
    $total = $prices['part_payments']['second_payment'];

    // Get plugin settings
    $settings = get_option('wpbs_settings', array());

    // Invoice item description
    $invoice_item_description = (!empty($settings['payment_authorize_net_invoice_name_translation_' . $post_data['language']])) ? $settings['payment_authorize_net_invoice_name_translation_' . $post_data['language']] : (!empty($settings['payment_authorize_net_invoice_name']) ? $settings['payment_authorize_net_invoice_name'] : get_bloginfo('name') . ' Booking');

    // Capture Order
    $transaction = WPBS_AuthorizeNet::createAnAcceptPaymentTransaction($total, $post_data['wpbs-authorize-net-value'], $payment->get('booking_id') . '-2', $invoice_item_description);

    if ($transaction['status'] == 'success') {

        $order = WPBS_AuthorizeNet::getTransactionDetails($transaction['transaction_id']);

        $details['final_payment'] = $order;
        $details['part_payments']['final_payment'] = true;

        $details['raw']['transaction_id'] .= ', ' . $order['transaction_id'];

        $details['raw']['amount'] = $details['raw']['amount'] + $order['amount'];

        $status = 'completed';
    } else {
        $details['error'] = $transaction['error_code'] . ': ' . $transaction['error_message'];
        $status = 'error';
    }

    $payment_data = array(
        'order_status' => $status,
        'details' => $details,
    );

    // Save Order
    wpbs_update_payment($payment->get('id'), $payment_data);
}
add_action('wpbs_save_final_payment_authorize_net', 'wpbs_save_final_payment_authorize_net', 10, 2);
