<?php

//https://github.com/AuthorizeNet/sample-code-php/blob/9ce85f72801b96adcf882a63ed3bfcdb1d14c5f0/PaymentTransactions/refund-transaction.php

// #visa 4007000000027

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

add_filter('wpbs_payment_details_refunds_available', function ($status, $payment) {
    if ($payment->get_payment_gateway() == 'authorize_net') {
        return true;
    }
    return $status;
}, 10, 2);

add_filter('wpbs_payment_details_refund_charges', function ($charges, $payment) {

    if ($payment->get_payment_gateway() != 'authorize_net') {
        return $charges;
    }

    $payment_details = $payment->get('details');


    include_once WPBS_AN_PLUGIN_DIR . 'includes/libs/authorize-net-sdk/authorize-net-sdk.php';

    $charge_ids = [];
    if (!$payment->is_part_payment() && isset($payment_details['raw']['transaction_id'])) {
        $charge_ids[] = [
            'id' => $payment_details['raw']['transaction_id'],
            'name' => 'Charge',
        ];
    } else {
        if ($payment->is_deposit_paid() && isset($payment_details['raw']['transaction_id'])) {
            $charge_ids[] = [
                'id' => trim(explode(',', $payment_details['raw']['transaction_id'])[0]),
                'name' => __('Deposit', 'wp-booking-system-authorize-net'),
            ];
        }
        if ($payment->is_final_payment_paid() && isset($payment_details['final_payment']['transaction_id'])) {
            $charge_ids[] = [
                'id' => $payment_details['final_payment']['transaction_id'],
                'name' => __('Final Payment', 'wp-booking-system-authorize-net'),
            ];
        }
    }

    $refunds = [];
    if (isset($payment_details['refunds'])) {
        foreach ($payment_details['refunds'] as $refund) {
            if (!isset($refunds[$refund['charge']])) {
                $refunds[$refund['charge']] = 0;
            }

            $refunds[$refund['charge']] += $refund['amount'];
        }
    }

    foreach ($charge_ids as $charge_id) {
        $charge = WPBS_AuthorizeNet::getTransactionDetails($charge_id['id']);
        
        if ($charge['status'] == 'error') {
            echo $charge['error_code'] . ': ' . $charge['error_message'];
            wp_die();
        }

        if($charge['status'] != 'settledSuccessfully'){
            continue;
        }

        $id = $charge['transaction_id'];

        $refunded = isset($refunds[$id]) ? $refunds[$id] : 0;

        $amount = $charge['amount'];
    
        $charges[] = [
            'name' => $charge_id['name'],
            'id' => $id,
            'amount' => $amount,
            'refunded' => $refunded,
            'available' => ($amount - $refunded),
        ];

    }

    return $charges;
}, 10, 3);

/**
 * Remove scheduled event
 *
 */
function wpbs_process_refund_authorize_net($charge_id, $amount, $payment)
{

    if (empty($charge_id)) {
        return ['error' => true, 'error_message' => 'Missing Charge ID'];
    }

    if (empty($amount)) {
        return ['error' => true, 'error_message' => 'Missing Amount'];
    }

    $amount = floatval($amount);

    // Include Authorize.net API
    include_once WPBS_AN_PLUGIN_DIR . 'includes/libs/authorize-net-sdk/authorize-net-sdk.php';

    $charge = WPBS_AuthorizeNet::getTransactionDetails($charge_id);

    $response = WPBS_AuthorizeNet::refundTransaction($charge, $amount);

    if (isset($response['error']) && $response['error']) {
        return ['error' => true, 'error_message' => $response['error_message']];
    }

    return ['success' => true, 'response' => $response, 'amount' => $amount];

}
