<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Includes the Base files
 *
 */
function wpbs_an_include_files_base()
{
    // Get legend dir path
    $dir_path = plugin_dir_path(__FILE__);

    // Include Payment Ajax Functions
    if (file_exists($dir_path . 'functions-actions-authorize-net.php')) {
        include $dir_path . 'functions-actions-authorize-net.php';
    }

    // Include Part Payments Functions
    if (file_exists($dir_path . 'functions-part-payments.php')) {
        include $dir_path . 'functions-part-payments.php';
    }

    // Include Refund Functions
    if (file_exists($dir_path . 'functions-refunds.php')) {
        include $dir_path . 'functions-refunds.php';
    }
}
add_action('wpbs_an_include_files', 'wpbs_an_include_files_base');

/**
 * Register Payment Method
 *
 * @param array
 *
 */
function wpbs_an_register_payment_method($payment_methods)
{
    $payment_methods['authorize_net'] = 'Authorize.Net';
    return $payment_methods;
}
add_filter('wpbs_payment_methods', 'wpbs_an_register_payment_method');

/**
 * Default form values
 *
 */
function wpbs_an_settings_authorize_net_defaults()
{
    return array(
        'display_name' => __('Authorize.Net', 'wp-booking-system-authorize-net'),
        'description' => __('Pay with your credit card through Authorize.Net.', 'wp-booking-system-authorize-net')
    );
}

/**
 * Check if payment method is enabled in settings page
 *
 */
function wpbs_an_form_outputter_payment_method_enabled_authorize_net($active)
{
    $settings = get_option('wpbs_settings', array());
    if (isset($settings['payment_authorize_net_enable']) && $settings['payment_authorize_net_enable'] == 'on') {
        return true;
    }
    return false;
}
add_filter('wpbs_form_outputter_payment_method_enabled_authorize_net', 'wpbs_an_form_outputter_payment_method_enabled_authorize_net');

/**
 * Get the payment method's name
 *
 */
function wpbs_an_form_outputter_payment_method_name_authorize_net($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_authorize_net_name_translation_' . $language])) {
        return $settings['payment_authorize_net_name_translation_' . $language];
    }
    if (!empty($settings['payment_authorize_net_name'])) {
        return $settings['payment_authorize_net_name'];
    }
    return wpbs_an_settings_authorize_net_defaults()['display_name'];
}
add_filter('wpbs_form_outputter_payment_method_name_authorize_net', 'wpbs_an_form_outputter_payment_method_name_authorize_net', 10, 2);

/**
 * Get the payment method's name
 *
 */
function wpbs_an_form_outputter_payment_method_description_authorize_net($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_authorize_net_description_translation_' . $language])) {
        return $settings['payment_authorize_net_description_translation_' . $language];
    }
    if (!empty($settings['payment_authorize_net_description'])) {
        return $settings['payment_authorize_net_description'];
    }
    return wpbs_an_settings_authorize_net_defaults()['description'];
}
add_filter('wpbs_form_outputter_payment_method_description_authorize_net', 'wpbs_an_form_outputter_payment_method_description_authorize_net', 10, 2);

/**
 * Returns an array of all the supported currencies
 * 
 * @return array
 */
function wpbs_an_supported_currencies(){
    return array('USD', 'CAD', 'CHF', 'DKK', 'EUR', 'GBP', 'NOK', 'PLN', 'SEK', 'AUD', 'NZD');
}